# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.tags_api import TagsApi  # noqa: E501


class TestTagsApi(unittest.TestCase):
    """TagsApi unit test stubs"""

    def setUp(self):
        self.api = TagsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_tag(self):
        """Test case for create_tag

        Createtag  # noqa: E501
        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        Gettag  # noqa: E501
        """
        pass

    def test_search_tag(self):
        """Test case for search_tag

        Searchtag  # noqa: E501
        """
        pass

    def test_update_tag(self):
        """Test case for update_tag

        Updatetag  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
