# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.reviews_api import ReviewsApi  # noqa: E501


class TestReviewsApi(unittest.TestCase):
    """ReviewsApi unit test stubs"""

    def setUp(self):
        self.api = ReviewsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_review(self):
        """Test case for create_review

        Create  # noqa: E501
        """
        pass

    def test_delete_review(self):
        """Test case for delete_review

        Deletereview  # noqa: E501
        """
        pass

    def test_get_review(self):
        """Test case for get_review

        Getreview  # noqa: E501
        """
        pass

    def test_search_reviews(self):
        """Test case for search_reviews

        Searchreview  # noqa: E501
        """
        pass

    def test_update_review(self):
        """Test case for update_review

        Updatereview  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
