# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.catalogs_api import CatalogsApi  # noqa: E501


class TestCatalogsApi(unittest.TestCase):
    """CatalogsApi unit test stubs"""

    def setUp(self):
        self.api = CatalogsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_attach_product_to_catalog(self):
        """Test case for attach_product_to_catalog

        Addproducttocatalog  # noqa: E501
        """
        pass

    def test_create_catalog(self):
        """Test case for create_catalog

        Createcatalog  # noqa: E501
        """
        pass

    def test_delete_catalog(self):
        """Test case for delete_catalog

        Deletecatalog  # noqa: E501
        """
        pass

    def test_detach_product_from_catalog(self):
        """Test case for detach_product_from_catalog

        Removeproductfromcatalog  # noqa: E501
        """
        pass

    def test_get_catalog(self):
        """Test case for get_catalog

        Getcatalog  # noqa: E501
        """
        pass

    def test_search_catalog_products(self):
        """Test case for search_catalog_products

        Searchcatalogproducts  # noqa: E501
        """
        pass

    def test_search_catalogs(self):
        """Test case for search_catalogs

        Searchcatalogs  # noqa: E501
        """
        pass

    def test_update_catalog(self):
        """Test case for update_catalog

        Updatecatalog  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
