# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.model.create_project_credit import CreateProjectCredit


class TestCreateProjectCredit(unittest.TestCase):
    """CreateProjectCredit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_CreateProjectCredit(self):
        """Test CreateProjectCredit"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateProjectCredit()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
