# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

from ehelply_python_experimental_sdk.api_client import ApiClient
from ehelply_python_experimental_sdk.api.tags_api_endpoints.create_tag import CreateTag
from ehelply_python_experimental_sdk.api.tags_api_endpoints.get_tag import GetTag
from ehelply_python_experimental_sdk.api.tags_api_endpoints.search_tag import SearchTag
from ehelply_python_experimental_sdk.api.tags_api_endpoints.update_tag import UpdateTag


class TagsApi(
    CreateTag,
    GetTag,
    SearchTag,
    UpdateTag,
    ApiClient,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
