# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.staff_api import StaffApi  # noqa: E501


class TestStaffApi(unittest.TestCase):
    """StaffApi unit test stubs"""

    def setUp(self):
        self.api = StaffApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_staff(self):
        """Test case for create_staff

        Createstaff  # noqa: E501
        """
        pass

    def test_delete_staff(self):
        """Test case for delete_staff

        Deletestaff  # noqa: E501
        """
        pass

    def test_get_staff(self):
        """Test case for get_staff

        Getstaff  # noqa: E501
        """
        pass

    def test_search_staff(self):
        """Test case for search_staff

        Searchstaff  # noqa: E501
        """
        pass

    def test_update_staff(self):
        """Test case for update_staff

        Updatestaff  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
