# coding: utf-8

"""
    eHelply SDK - 1.1.106

    eHelply SDK for SuperStack Services  # noqa: E501

    The version of the OpenAPI document: 1.1.106
    Contact: support@ehelply.com
    Generated by: https://openapi-generator.tech
"""

import unittest

import ehelply_python_experimental_sdk
from ehelply_python_experimental_sdk.api.products_api import ProductsApi  # noqa: E501


class TestProductsApi(unittest.TestCase):
    """ProductsApi unit test stubs"""

    def setUp(self):
        self.api = ProductsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_product(self):
        """Test case for create_product

        Createproduct  # noqa: E501
        """
        pass

    def test_delete_product(self):
        """Test case for delete_product

        Deleteproduct  # noqa: E501
        """
        pass

    def test_get_product(self):
        """Test case for get_product

        Getproduct  # noqa: E501
        """
        pass

    def test_search_product_catalog(self):
        """Test case for search_product_catalog

        Searchproductcatalog  # noqa: E501
        """
        pass

    def test_search_products(self):
        """Test case for search_products

        Searchproducts  # noqa: E501
        """
        pass

    def test_update_product(self):
        """Test case for update_product

        Updateproduct  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
